@@ -24,15 +24,23 @@ import time
 import paramiko
 
 
-class GerritWatcher(threading.Thread):
+class GerritWatcher(object):
     log = logging.getLogger("gerrit.GerritWatcher")
 
-    def __init__(self, gerrit, username, hostname, port=29418, keyfile=None):
-        threading.Thread.__init__(self)
-        self.username = username
-        self.keyfile = keyfile
-        self.hostname = hostname
-        self.port = port
+    def __init__(
+            self, gerrit, username=None, hostname=None, port=None,
+            keyfile=None):
+        """Create a GerritWatcher.
+
+        :param gerrit: A Gerrit instance to pass events to.
+
+        All other parameters are optional and if not supplied are sourced from
+        the gerrit instance.
+        """
+        self.username = username or gerrit.username
+        self.keyfile = keyfile or gerrit.keyfile
+        self.hostname = hostname or gerrit.hostname
+        self.port = port or gerrit.port
         self.gerrit = gerrit
 
     def _read(self, fd):
@@ -95,12 +103,8 @@ class Gerrit(object):
 
     def startWatching(self):
         self.event_queue = Queue.Queue()
-        self.watcher_thread = GerritWatcher(
-            self,
-            self.username,
-            self.hostname,
-            port=self.port,
-            keyfile=self.keyfile)
+        self.watcher_thread = threading.Thread(target=GerritWatcher(self).run)
+        self.watcher_thread.daemon = True
         self.watcher_thread.start()
 
     def addEvent(self, data):
@@ -137,6 +141,11 @@ class Gerrit(object):
         out, err = self._ssh(cmd)
         return out.split('\n')
 
+    def replicate(self, project='--all'):
+        cmd = 'gerrit replicate %s' % project
+        out, err = self._ssh(cmd)
+        return out.split('\n')
+
     def review(self, project, change, message, action={}):
         cmd = 'gerrit review %s --project %s' % (change, project)
         if message:
